@@ -1,10 +1,12 @@
 ### SHELL> mpiexec -np 2 Rscript --vanilla [...].r
 
+### Initial.
 library(pbdMPI, quietly = TRUE)
 init()
 .comm.size <- comm.size()
 .comm.rank <- comm.rank()
 
+### Examples.
 N <- 5
 x.total <- (.comm.size + 1) * .comm.size / 2
 x <- 1:x.total
@@ -12,7 +14,7 @@ x.count <- 1:.comm.size
 comm.cat("Original x:\n", quiet = TRUE)
 comm.print(x)
 
-y <- scatter(split(x, rep(x.count, x.count)))     # return the element of list.
+y <- scatter(split(x, rep(x.count, x.count)))    ### return the element of list.
 comm.cat("\nScatter list:\n", quiet = TRUE)
 comm.print(y)
 
@@ -24,5 +26,5 @@ y <- scatter(as.double(x), double(.comm.rank + 1), as.integer(x.count))
 comm.cat("\nScatterv double:\n", quiet = TRUE)
 comm.print(y, rank.print = 1)
 
+### Finish.
 finalize()
-
