@@ -32,8 +32,8 @@ SEXP spmd_initialize(){
 #endif
 	}
 
-	MPI_Errhandler_set(MPI_COMM_WORLD, MPI_ERRORS_RETURN);
-	MPI_Errhandler_set(MPI_COMM_SELF, MPI_ERRORS_RETURN);
+	MPI_Comm_set_errhandler(MPI_COMM_WORLD, MPI_ERRORS_RETURN);
+	MPI_Comm_set_errhandler(MPI_COMM_SELF, MPI_ERRORS_RETURN);
 	if(comm == NULL){
 		comm = (MPI_Comm *) Calloc(COMM_MAXSIZE, MPI_Comm); 
 		comm[0] = MPI_COMM_WORLD;
